# Example Poll 1: Single-answer questions.
Results of an opinion poll made in Israel circa 3/2024, to check the public opinion regarding a prisoner swap deal. 

The poll is simple, and contains only single-answer questions.

See [analyze.py](analyze.py) for usage example.
